@@ -6,11 +6,11 @@ _template = Template("""app.controller("${name}Controller", function ($$scope, $
     $$log.debug("${name} Controller Initialized");
 });""")
 
-def generate_controller(dir, name):
-    controller = "app" + os.sep + "controllers" + os.sep + name.lower() + "Controller.js"
+def generate_controller(directory, name):
+    controller = os.path.join("app", "controllers", name.lower() + "Controller.js")
     title = name.title()
-    with open(dir + os.sep + 'assets' + os.sep + controller, 'w') as f:
-        f.write(_template.substitute(name=name.title()))
+    with open(os.path.join(directory, 'assets', controller), 'w') as f:
+        f.write(_template.substitute(name=title))
 
 if __name__ == "__main__":
     generate_controller('../..', 'category')
\ No newline at end of file
